@@ -4,6 +4,7 @@
  *   Copyright 2010-2011, Christian Muehlhaeuser <muesli@tomahawk-player.org>
  *   Copyright 2011, Leo Franchi <lfranchi@kde.org>
  *   Copyright 2010-2011, Jeff Mitchell <jeff@tomahawk-player.org>
+ *   Copyright 2013, Uwe L. Korn <uwelk@xhochy.com>
  *
  *   Tomahawk is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -26,11 +27,10 @@
 
 #include "AvatarManager.h"
 
-#ifndef ENABLE_HEADLESS
-    #include "XmlConsole.h"
-#endif
+#include "XmlConsole.h"
 
 #include "accounts/AccountDllMacro.h"
+#include "accounts/Account.h"
 
 #include "../XmppInfoPlugin.h"
 
@@ -48,10 +48,7 @@
 #include <jreen/mucroom.h>
 #include <jreen/pubsubmanager.h>
 
-#ifndef ENABLE_HEADLESS
-    #include <QMessageBox>
-#endif
-
+#include <QMessageBox>
 
 class ACCOUNTDLLEXPORT XmppSipPlugin : public SipPlugin
 {
@@ -69,9 +66,7 @@ public:
 
     Tomahawk::InfoSystem::InfoPluginPtr infoPlugin();
 
-#ifndef ENABLE_HEADLESS
     virtual QMenu* menu();
-#endif
 
     // used by XmppAccount to expose connection state and controls
     Tomahawk::Accounts::Account::ConnectionState connectionState() const;
@@ -88,9 +83,9 @@ public slots:
     virtual void disconnectPlugin();
     virtual void checkSettings();
     virtual void configurationChanged();
-    virtual void addContact( const QString& peerId, const QString& msg = QString() );
+    virtual bool addContact( const QString& peerId, AddContactOptions options = NoOptions, const QString& msg = QString() );
 
-    virtual void sendSipInfo( const Tomahawk::peerinfo_ptr& receiver, const SipInfo& info );
+    virtual void sendSipInfos( const Tomahawk::peerinfo_ptr& receiver, const QList<SipInfo>& info );
 
     void showAddFriendDialog();
     void publishTune( const QUrl& url, const Tomahawk::InfoSystem::InfoStringHash& trackInfo );
@@ -144,15 +139,17 @@ private:
     QHash< Jreen::JID, Jreen::Presence::Type > m_peers;
     QHash< QString, QString > m_jidsNames;
 
-#ifndef ENABLE_HEADLESS
     QHash< Jreen::JID, QMessageBox* > m_subscriptionConfirmBoxes;
     QMenu* m_menu;
     XmlConsole* m_xmlConsole;
-#endif
 
     enum IqContext { NoContext, RequestDisco, RequestedDisco, SipMessageSent, RequestedVCard, RequestVersion, RequestedVersion };
     AvatarManager* m_avatarManager;
     Jreen::PubSub::Manager* m_pubSubManager;
+    QMap< QString, Tomahawk::peerinfo_ptr > peersWaitingForSip;
+    QMap< QString, Tomahawk::peerinfo_ptr > peersWaitingForVersionString;
+    QMap< QString, QList< SipInfo > > sipinfosQueue;
+    QMutex peerQueueMutex;
 };
 
 #endif
