@@ -19,20 +19,25 @@
 
 #include "ResolverAccount.h"
 
-#include "AccountManager.h"
-#include "AtticaManager.h"
-#include "resolvers/ExternalResolver.h"
-#include "resolvers/ExternalResolverGui.h"
-#include "Pipeline.h"
-#include "TomahawkSettings.h"
-#include "Artist.h"
-#include "Album.h"
-#include "Source.h"
-#include "utils/Logger.h"
-#include "qjson/parser.h"
 #include "jobview/JobStatusView.h"
 #include "jobview/JobStatusModel.h"
 #include "jobview/ErrorStatusMessage.h"
+#include "AccountManager.h"
+#include "AtticaManager.h"
+#include "ConfigStorage.h"
+#include "resolvers/ExternalResolver.h"
+#include "resolvers/ExternalResolverGui.h"
+#include "utils/Json.h"
+#include "utils/Logger.h"
+
+#include "Album.h"
+#include "Artist.h"
+#include "AccountManager.h"
+#include "AtticaManager.h"
+#include "Pipeline.h"
+#include "PlaylistEntry.h"
+#include "Source.h"
+#include "TomahawkSettings.h"
 #include "TomahawkVersion.h"
 
 #include <QFile>
@@ -222,9 +227,8 @@ ResolverAccountFactory::metadataFromJsonFile( const QString& path )
     QFile metadataFile( path );
     if ( metadataFile.open( QIODevice::ReadOnly | QIODevice::Text ) )
     {
-        QJson::Parser parser;
         bool ok;
-        QVariantMap variant = parser.parse( metadataFile.readAll(), &ok ).toMap();
+        QVariantMap variant = TomahawkUtils::parseJson( metadataFile.readAll(), &ok ).toMap();
 
         if ( ok )
         {
@@ -299,6 +303,10 @@ ResolverAccount::ResolverAccount( const QString& accountId, const QString& path,
 
     setConfiguration( configuration );
 
+    //just init so this account is tracked by LCS, we'll sync later
+    if ( !AccountManager::instance()->configStorageForAccount( accountId ) )
+        AccountManager::instance()->localConfigStorage()->save( accountId, Account::Configuration() );
+
     init( path );
 
     sync();
@@ -341,7 +349,7 @@ ResolverAccount::hookupResolver()
     if ( configuration().contains( "scripts" ) )
         additionalPaths = configuration().value( "scripts" ).toStringList();
 
-    Tomahawk::ExternalResolver* er = Pipeline::instance()->addScriptResolver( mainScriptPath, additionalPaths );
+    Tomahawk::ExternalResolver* er = Pipeline::instance()->addScriptResolver( accountId(), mainScriptPath, additionalPaths );
     m_resolver = QPointer< ExternalResolverGui >( qobject_cast< ExternalResolverGui* >( er ) );
     connect( m_resolver.data(), SIGNAL( changed() ), this, SLOT( resolverChanged() ) );
 
@@ -552,9 +560,9 @@ AtticaResolverAccount::loadIcon()
     if ( m_resolver.isNull() )
         return;
 
-
     m_icon = AtticaManager::instance()->iconForResolver( AtticaManager::instance()->resolverForId( m_atticaId ) );
-    m_resolver.data()->setIcon( m_icon );
+    if ( !m_icon.isNull() )
+        m_resolver.data()->setIcon( m_icon );
 }
 
 
